Gesellschaft für Internationale Zusammenarbeit (GIZ)
****************************************************

GIZ GmbH (`website <https://www.giz.de/en/>`_, lit. *Corporation for International Development*) is the main German development agency.
It is not currently a direct provider of (meta)data through TDC, but its members initiated what is now the TDCI and support its activities, including development of this :mod:`.transport_data` package.
This work mainly appears in the :mod:`.org` and :mod:`.proto` modules.

.. _project-tuewas:

TUEWAS
======

- “Transport, Environment, Energy, and Water in Asia” is an “internal sector network” of GIZ.
- Website: https://tuewas-asia.org
